# IndraDB python client [![Build Status](https://travis-ci.org/indradb/python-client.svg?branch=master)](https://travis-ci.org/indradb/python-client)

IndraDB's python client. This uses the server API to enable graph queries and manipulation from python code.

See the [api doc](https://htmlpreview.github.io/?https://github.com/indradb/python-client/blob/master/doc/indradb/index.html) for more info.

## Running tests

    make init test
